/* This date time is from the last non-merge commit to Hamlib. */
#define HAMLIBDATETIME "Thu Dec 08 15:11:46 2022 +0000 SHA=75fbd0"
